@@ -75,15 +75,24 @@ class SensiboClient:
             # Add information for Element model
             etoh = measure.get("etoh")
             iaq = measure.get("iaq")
+            rcda = measure.get("rcda")
 
             ac_states: dict[str, Any] = dev["acState"]
             target_temperature = ac_states.get("targetTemperature")
             hvac_mode = ac_states.get("mode")
             running = ac_states.get("on")
-            fan_mode = ac_states.get("fanLevel")
-            swing_mode = ac_states.get("swing")
-            horizontal_swing_mode = ac_states.get("horizontalSwing")
-            light_mode = ac_states.get("light")
+            fan_mode: str | None = ac_states.get("fanLevel")
+            if fan_mode:
+                fan_mode = fan_mode.lower()
+            swing_mode: str | None = ac_states.get("swing")
+            if swing_mode:
+                swing_mode = swing_mode.lower()
+            horizontal_swing_mode: str | None = ac_states.get("horizontalSwing")
+            if horizontal_swing_mode:
+                horizontal_swing_mode = horizontal_swing_mode.lower()
+            light_mode: str | None = ac_states.get("light")
+            if light_mode:
+                light_mode = light_mode.lower()
             available = dev["connectionStatus"].get("isAlive", True)
             capabilities: dict[str, Any] = dev["remoteCapabilities"]
             hvac_modes = list(capabilities.get("modes", []))
@@ -97,10 +106,40 @@ class SensiboClient:
             current_capabilities: dict[str, Any] = capabilities["modes"][
                 ac_states.get("mode")
             ]
-            fan_modes = current_capabilities.get("fanLevels")
-            swing_modes = current_capabilities.get("swing")
-            horizontal_swing_modes = current_capabilities.get("horizontalSwing")
-            light_modes = current_capabilities.get("light")
+            fan_modes: list[str] | None = current_capabilities.get("fanLevels")
+            fan_modes_to_native: dict | None = None
+            if fan_modes:
+                fan_modes_to_native = {
+                    _fan_mode.lower(): _fan_mode for _fan_mode in fan_modes
+                }
+                fan_modes = [_fan_mode.lower() for _fan_mode in fan_modes]
+            swing_modes: list[str] | None = current_capabilities.get("swing")
+            swing_modes_to_native: dict | None = None
+            if swing_modes:
+                swing_modes_to_native = {
+                    _swing_mode.lower(): _swing_mode for _swing_mode in swing_modes
+                }
+                swing_modes = [_swing_mode.lower() for _swing_mode in swing_modes]
+            horizontal_swing_modes: list[str] | None = current_capabilities.get(
+                "horizontalSwing"
+            )
+            horizontal_swing_modes_to_native: dict | None = None
+            if horizontal_swing_modes:
+                horizontal_swing_modes_to_native = {
+                    _horizontal_mode.lower(): _horizontal_mode
+                    for _horizontal_mode in horizontal_swing_modes
+                }
+                horizontal_swing_modes = [
+                    _horizontal_mode.lower()
+                    for _horizontal_mode in horizontal_swing_modes
+                ]
+            light_modes: list[str] | None = current_capabilities.get("light")
+            light_modes_to_native: dict | None = None
+            if light_modes:
+                light_modes_to_native = {
+                    _light_mode.lower(): _light_mode for _light_mode in light_modes
+                }
+                light_modes = [_light_mode.lower() for _light_mode in light_modes]
             temperature_unit_key = dev.get("temperatureUnit") or ac_states.get(
                 "temperatureUnit"
             )
@@ -234,7 +273,9 @@ class SensiboClient:
             smart_on = None
             if dev["productModel"] != "pure":
                 smart_on = smart.get("enabled", False)
-            smart_type = smart.get("type")
+            smart_type: str | None = smart.get("type")
+            if smart_type:
+                smart_type = smart_type.lower()
             smart_low_temp_threshold = smart.get("lowTemperatureThreshold")
             smart_high_temp_threshold = smart.get("highTemperatureThreshold")
             smart_low_state = smart.get("lowTemperatureState")
@@ -280,9 +321,13 @@ class SensiboClient:
                 available=available,
                 hvac_modes=hvac_modes,
                 fan_modes=fan_modes,
+                fan_modes_to_native=fan_modes_to_native,
                 swing_modes=swing_modes,
+                swing_modes_to_native=swing_modes_to_native,
                 horizontal_swing_modes=horizontal_swing_modes,
+                horizontal_swing_modes_to_native=horizontal_swing_modes_to_native,
                 light_modes=light_modes,
+                light_modes_to_native=light_modes_to_native,
                 temp_unit=temperature_unit_key,
                 temp_list=temperatures_list,
                 temp_step=temperature_step,
@@ -322,6 +367,7 @@ class SensiboClient:
                 schedules=schedules,
                 etoh=etoh,
                 iaq=iaq,
+                rcda=rcda,
             )
 
         return SensiboData(raw=data, parsed=device_data)
